Index: trunk/webapps/unifiedlogger/logging_service.py
===================================================================
--- trunk/webapps/unifiedlogger/logging_service.py	(revision 433)
+++ trunk/webapps/unifiedlogger/logging_service.py	(revision 439)
@@ -1,10 +1,11 @@
-import cms_watcher, cad_watcher, time, json
+import cms_watcher, cad_watcher, time, json, ConfigParser
 # Unified Logging Service
 # jdalbey 7/6/2019
 
+outputFilename = "unifiedlog.csv"
 
 # Load the sim time file and extract the seconds */
 def getSimTime():
-    with open ("../dynamicdata/sim_elapsedtime.json", 'r') as myfile:
+    with open ("webapps/dynamicdata/sim_elapsedtime.json", 'r') as myfile:
         jsonData=myfile.read()
          
@@ -15,9 +16,12 @@
     return  "%d:%02d:%02d" % (h, m, s)    
 
-def main():
+def startup():
+    # get path to output file from configuration
+    config = ConfigParser.ConfigParser()
+    config.read('config/logging_service.cfg')
+    logfilepath  = config.get('Paths', 'UnifiedLogPath')
+    
     # Delete any previously existing output file
-    f = open("../dynamicdata/unifiedlog.html", "w")
-    startHTML = "<HTML><HEAD><meta http-equiv=\"refresh\" content=\"5\" /></HEAD><BODY><PRE>"
-    f.write(startHTML);
+    f = open(logfilepath + outputFilename, "w")
     f.close()            
     # List of the available plugin modules 
@@ -51,18 +55,20 @@
                 trimmed_item = item.strip()
                 if len(trimmed_item) > 0:
-                    output += timeStamp + " " + trimmed_item + "\n"
+                    output += timeStamp + ", " + trimmed_item + "\n"
     #    END LOOP
     #    IF the Output Buffer has any contents THEN
         if len(output) > 0:
     #       Write (append) Output Buffer to unified log file 
             print output,
-            f = open("../dynamicdata/unifiedlog.html", "a")
+            f = open(logfilepath + outputFilename, "a")
             f.write(output)
             f.close()            
     #    END IF
-    #    Wait one second
-        time.sleep(1)
+    #    Wait five seconds
+        time.sleep(5)
 
 #END DO
-if __name__ == "__main__":
-    main()
+
+if __name__ == '__main__':
+    startup()
@@ -51,18 +55,20 @@
     #    IF the Output Buffer has any contents THEN
         if len(output) > 0:
-    #       Write (append) Output Buffer to unified log file 
+    #       Write (append) Output Buffer to unified log file as CSV
+    #       Assumes fields don't contain commas 
             print output,
